@@ -21,8 +21,8 @@ class JointParam(BaseModel):
 
 class ImuSensor(BaseModel):
     body_name: str
-    pos: list[float] = [0.0, 0.0, 0.0]
-    quat: list[float] = [1.0, 0.0, 0.0, 0.0]
+    pos: list[float] | None = None
+    rpy: list[float] | None = None
     acc_noise: float | None = None
     gyro_noise: float | None = None
     mag_noise: float | None = None
@@ -31,24 +31,37 @@ class ImuSensor(BaseModel):
 class CameraSensor(BaseModel):
     name: str
     mode: str
-    pos: list[float] = [0.0, 0.0, 0.0]
-    quat: list[float] = [1.0, 0.0, 0.0, 0.0]
+    pos: list[float] | None = None
+    rpy: list[float] | None = None
     fovy: float = 45.0
 
 
+class FeetSpheresParams(BaseModel):
+    foot_links: list[str]
+    sphere_radius: float
+
+
 class ConversionMetadata(BaseModel):
     collision_params: CollisionParams = CollisionParams()
     joint_params: list[JointParam] | None = None
     imus: list[ImuSensor] = []
     cameras: list[CameraSensor] = [
         CameraSensor(
-            name="tracking_camera",
+            name="front_camera",
             mode="track",
-            pos=[0, -2.0, 1.0],
-            quat=[0.7071, 0.3827, 0, 0],
+            pos=[0, 2.0, 0.5],
+            rpy=[90.0, 0.0, 180.0],
+            fovy=90,
+        ),
+        CameraSensor(
+            name="side_camera",
+            mode="track",
+            pos=[-2.0, 0.0, 0.5],
+            rpy=[90.0, 0.0, 270.0],
             fovy=90,
         ),
     ]
+    feet_spheres: FeetSpheresParams | None = None
     remove_redundancies: bool = True
     floating_base: bool = True
 
